@@ -7,7 +7,7 @@
 @desc   : 
 @exec   : 
 """
-
+import sys
 import pymysql
 from pymysql.cursors import DictCursor
 
@@ -17,15 +17,27 @@ class Conn(object):
 
     def __init__(self, **config):
         """初始化数据库信息并创建数据库连接"""
+        if config:
+            for k, v in config.items():
+                if k == 'charset' and v not in ('utf8', 'utf8mb4'):
+                    config[k] = 'utf8mb4'
+                if k == 'port' and not isinstance(v, int):
+                    try:
+                        config[k] = int(v)
+                    except:
+                        config[k] = 3306
+        else:
+            sys.exit("Connect config can not be empty!")
+
         try:
             self.conn = pymysql.connect(**config)
         except Exception as e:
-            exit(e)
+            sys.exit(e)
         try:
             # 测试mysql是否通
             self.cur = self.conn.cursor()
         except Exception as e:
-            exit(e)
+            sys.exit(e)
 
     def select(self, select_sql, return_type=None):
         """执行select, show 类查询，有返回值"""
